function [sys, inter, bas] = dat_AMX(parameters,sys,inter,bas,q_index)

% SPIN SYSTEM ------------------------------------------------------------
    
% Chemical shifts, and T1 and T2 time constants

    % 1H
    shifts_1H = {7.6077 4.8266 1.0296};        % 1H chemical shifts in ppm
    t1_1H=[1.0 1.0 1.0];                      % T1 relaxation TIME constants in (s)
    t2_1H=[0.5 0.5 0.5];                      % T2 relaxation TIME constants in (s) 


% Numbers of spins
num_1H = length(shifts_1H);    
total_spins = num_1H;

% Generate sys.isotopes
sys.isotopes = {};
sys.isotopes = [sys.isotopes, repmat({'1H'}, 1, num_1H)];

% Generate chemical shift and relaxation parameters in inter structure
inter.zeeman.scalar = [shifts_1H];
inter.r1_rates = 1./[t1_1H];
inter.r2_rates = 1./[t2_1H];


% J-coupling constants

    % Define inter.coupling.scalar as a (total_spin x total_spin) cell
    % array
    inter.coupling.scalar = cell(total_spins);     

    inter.coupling.scalar{1,2}= 7.71;
    inter.coupling.scalar{2,3}= 6.93;
        
% LOGICAL MASK ---------------------------------------------------------- 

% Code practically unchanged from "strychnine.m" example in Spinach documentation    

% Create logical mask: an array with elements of 1 at the indexes where the 
% spins defined in parameters.isotopes are present in sys.isotopes and zero 
% in all other places

mask = ismember(sys.isotopes, parameters.isotopes);

% Apply the logical mask to the spin system parameter arrays to remove any
% values from spins not included in the simulation

sys.isotopes = sys.isotopes(mask);
inter.zeeman.scalar = inter.zeeman.scalar(mask);
inter.coupling.scalar = inter.coupling.scalar(mask,mask);
inter.r1_rates = inter.r1_rates(mask);
inter.r2_rates = inter.r2_rates(mask);

% -----------------------------------------------------------------------
% Relaxation model
inter.relaxation={'t1_t2'};
inter.rlx_keep='secular';
inter.equilibrium='zero';

% No idea what these are for
parameters.rlx_ph={};
parameters.rlx_op={};

% Sample geometry 
parameters.dims=0.015; % Sample length / m
parameters.npts=1000; % Number of points defining the sample
parameters.deriv={'period',7};
   
% Basis set specification
bas.formalism='sphten-liouv';
bas.approximation='IK-2';
bas.space_level=1;
bas.connectivity='scalar_couplings';

% Spinach housekeeping (part 1)
spin_system=create(sys,inter);

end
% Simulation ID: 230118-074203
