function [parameters, sys, inter, bas] = dat_sel_COSY_params(q_index)
%
% Parameters file for selective COSY experiment.
%
% ------------------------------------------------------------------------
% Daniel A, Taylor     Last modified: 2023/01/18
% ------------------------------------------------------------------------

% Create sys, parameters, bas and inter structures to avoid MATLAB output 
% error if they are undefined in this file
sys = struct; parameters = struct; inter = struct; bas = struct;

% Spectrometer parameters
sys.magnet = 11.7463508; % 500.130 MHz (1 T -> 42.5774785 MHz for 1H)

% Fnmode
parameters.fnmode = {'1D'};         % '1D','QF','EA','States'

% Simulation context
parameters.context = 'liquid';

% Sequence parameters
parameters.spins = {'1H'};        % Nuclei detected
parameters.decouple = {};
parameters.sweep = [10000];
% parameters.offset = (7.685 * (sys.magnet*spin('1H')/(2*pi*1e6)));
offset = 4.9066*sys.magnet*spin('1H')/(2*pi*1e6):-0.008*sys.magnet*spin('1H')/(2*pi*1e6):4.7466*sys.magnet*spin('1H')/(2*pi*1e6)
parameters.offset = offset(q_index);
parameters.npoints = [32768];
parameters.zerofill = [262144];

% Delay parameters
tau_mix = 10/1e3;
parameters.tau_mix = tau_mix;
parameters.delta = 0.002;

% Shape parameters
parameters.shape = {'reburp_1000.pk'};
parameters.shape_points = 1000;
parameters.shape_duration = 290700/1e6;
% parameters.shape_offset = (5.99 * (11.7463508*spin('1H')/(2*pi*1e6))) - parameters.offset(1);     % shape offset relative to spectrum offset
parameters.shape_offset = 0;
parameters.shape_spin = {'1H'};

% Relaxation parameters
%inter.relaxation = {'t1_t2'};
%inter.temperature = 298;

% % bas.approximation='IK-2';
% % bas.space_level=1;
% % bas.connectivity='scalar_couplings';
% % inter.equilibrium='zero';
% % inter.rlx_keep='kite';

% Spin system pruning
parameters.isotopes = {'1H'};   % Isotopes to be included in sys.isotopes 

% Plot parameters
parameters.axis_units = 'ppm';

% Kernel file saving
% parameters.kerlib_files = {};

% % Spinach log file
% sys.output = 'hush';


end
% Simulation ID: 230118-074203
