function [parameters, sys, inter, bas] = dat_GEMSTONE_CLIPCOSY_params(q_index)
%
% Params file for GEMSTONE CLIP-COSY experiment
%
% ------------------------------------------------------------------------
% Daniel A. Taylor     Last modified: 2021/12/01
% ------------------------------------------------------------------------

% Create sys, parameters and inter structures to avoid MATLAB output error
% if they are undefined in this file
sys = struct; parameters = struct; inter = struct; bas = struct;

% Spectrometer parameters
sys.magnet = 11.7463508; % 500.130 MHz (1 T -> 42.5774785 MHz for 1H)

% Fnmode
parameters.fnmode = {'1D'};         % '1D','QF','EA','States'

% Context
parameters.context = 'imaging';

% Phase cycle
parameters.nt = 8;

% Sequence parameters
parameters.spins = {'1H'};        % Nuclei detected
parameters.decouple = {};
parameters.sweep = [10000];
% parameters.offset = [2500];
% parameters.offset = 7.685*sys.magnet*spin('1H')/(2*pi*1e6);
offset = 4.9066*sys.magnet*spin('1H')/(2*pi*1e6):-0.008*sys.magnet*spin('1H')/(2*pi*1e6):4.7466*sys.magnet*spin('1H')/(2*pi*1e6)
parameters.offset = offset(q_index);
parameters.npoints = [32768];
parameters.zerofill = [262144];

% Delay parameters
tau_mix = 10/1e3;
parameters.tau_mix = tau_mix;
parameters.delta = 0.002;


% Shape parameters
parameters.shape = {'r_snob_1000.pk'};
parameters.shape_points = 1000;
parameters.shape_duration = 11660.0/1e6;
% parameters.shape_offset = (2.00*500.13)-parameters.offset(2);     % shape offset relative to spectrum offset
parameters.shape_offset = 0;
parameters.shape_spin = {'1H'};

% Chirp parameters
grad_percent=2.15;
parameters.g_amp=0.535*grad_percent/100;  % T/m; [G/cm = 100*T/m]
parameters.q_factor=11;         % Q factor for the chirp pulses
parameters.duration = 120000/1e6;      % pulse width of chirp (s)
parameters.bandwidth = 10000;     % sweep width of chirp (Hz)
parameters.pulsenpoints = 10000;  % number of points in the chirp
parameters.smfactor = 80;         % smoothing factor
parameters.chirptype = 'wurst'; 

% Sample parameters
parameters.dims = 0.015;  % m
parameters.npts = 1000;
parameters.deriv = {'period',7};

% % Diffusion and flow
% parameters.diff = 0;      % m^2/s
% parameters.u = zeros(parameters.npts,1);

% Imaging relaxation phantom
parameters.rlx_ph = {};
parameters.rlx_op = {};

% Relaxation parameters
% inter.relaxation = {'t1_t2'};
% inter.temperature = 298;
% inter.relaxation = {'damp'};
% inter.damp_rate = 0.0;
% inter.rlx_keep = 'diagonal';
% inter.equilibrium = 'zero';

% Spin system pruning
parameters.isotopes = {'1H'};   % Isotopes to be included in sys.isotopes 

% Spin dilution parameters
parameters.spin_dilution = 'none';

% Slice mode
parameters.slice_mode = 'sum';

% Plot parameters
parameters.axis_units = 'ppm';

% Console parameter
sys.output = 'hush';


end


% Simulation ID: 230117-161420
