function [sys, inter, bas] = hf_pople(parameters,sys,inter,bas,q_index,pople)
%
% A general sample file containing a large collection of samples in Pople
% notation. Set up for 1H, 19F and 1H-19F spin systems. 13C may also be 
% added to each spin system.
%
% INSTRUCTIONS ----------------------------------------------------------
%
% Edit sample parameters (chemical shifts, J-coupling constants, etc.) in
% the first ~130 lines of this file. For each nucleus (1H, 19F and 13C),
% there is only one version of each sample parameter*: e.g. only one 1H
% chemical shift value for an 'A' spin that is used for ALL spin systems
% (line 53). You shouldn't need to venture into the switch statements
% unless you want to do something special.
%
% *an exception to this is the J(AB) coupling constant, which has a "large"
% value that is used in some cases (AB_large, ABX, ABX3)
%
% FUNCTION ARGUMENTS ----------------------------------------------------
%
% Required:
% params    - @parameter file name
% q_index   - 1,2,3... (only used when queuing experiments; default 0)
% pople     - 'AX','AMX', etc. (see AVAILABLE SPIN SYSTEMS; default '')
%
% NOTE: @ symbol and quotation marks must be included where specified above
%
% AVAILABLE SPIN SYSTEMS ------------------------------------------------
% 
% NOTE: AAXX = AA'XX'
%
% Homonuclear systems:
% 1-spin: A
% 2-spin: A2, AX, AB, AB_large
% 3-spin: A3, AMX, ABX, ABC, AX2, AB2
% 4-spin: AMPX, ABCD, AX3, AB3, A2X2, A2B2, AAXX, AABB
% 5-spin: A2X3, A2B3, ABX3, AAMXX, AABBC
%
% Heteronuclear systems:
% 2-spin: AX_het 
% 3-spin: AX2_het
% 4-spin: AX3_het, A2X2_het, AAXX_het
% 5-spin: A2X3_het
% 
% ------------------------------------------------------------------------
% Howard Foster     Last modified: 2021/07/23
% ------------------------------------------------------------------------


%% SPIN SYSTEM -----------------------------------------------------------
    
% Chemical shifts (ppm)

%     sA = [5.0 4.97 4.93 4.90 4.87 4.83 4.8 4.77 4.73 4.7 4.67 4.63 4.6 4.57 4.53 4.5 4.47 4.43 4.4 4.37 4.33 4.3 4.27 4.23];
%     sX = [5.1 5.13 5.17 5.2 5.23 5.27 5.3 5.33 5.37 5.4 5.43 5.47 5.5 5.53 5.57 5.6 5.63 5.67 5.7 5.73 5.77 5.80 5.83 5.87];
% 
%     shifts_1H.A = sA(q_index);
%     shifts_1H.X = sX(q_index);
    
%     J_HH.AX = 8.00;
    
%     shifts_1H.A = (1e6*2500)/(spin('1H')*11.7463508/(2*pi));     
    
shifts_1H.A = 7.685;
shifts_1H.X = 7.086;
shifts_1H.M = 5.324;

    % 1H
%     shifts_1H.A = 3.72;           shifts_1H.B = 5.04;
%     shifts_1H.X = 8.00;           shifts_1H.C = 5.10;
    shifts_1H.M = 4.10;           shifts_1H.D = 5.17;
    shifts_1H.P = 6.50;           
    
    % 19F
    shifts_19F.A = -180.0;        shifts_19F.B = -181.0;
    shifts_19F.X = -120.0;        shifts_19F.C = -182.2;
    shifts_19F.M = -220.0;        shifts_19F.D = -183.0;
    shifts_19F.P = -160.0;        
    
    % 13C
%     shifts_13C = {80.0, 100.0, 130.0, 170.0};
    shifts_13C = {80.0, 100.0, 130.0, 170.0};
    

% J-coupling constants (Hz)
% NOTE: Trailing underscores denote magnetic inequivalence (AB_ = AB' = A'B) 

    % 1H-1H
    
    J_HH.AB = 8.00;         % General JAB (used in most cases)
    J_HH.AB_large = 15.00;  % JAB used in pople = 'AB_large', 'ABX' and 'ABX3'
     
    J_HH.AC = 3.00;         J_HH.CD = 0.80;         J_HH.AA_ = 2.50;              
    J_HH.AD = 10.00;                                J_HH.AB_ = 0.80;
%     J_HH.AM = 9.00;         J_HH.MP = 10.00;        J_HH.AM_ = 9.00;

% J_HH.AM = 7.00;
% J_HH.AM = 5.76;
J_HH.AM = 10;

% J_HH.MX = 4.00;
% J_HH.MX = 5.76;
% J_HH.MX = 5;
 J_HH.MX = 5;


%     J_HH.AP = 3.00;         J_HH.MX = 2.50;         J_HH.AX_ = 0.80;
%     J_HH.AX = 5.76;                                 J_HH.BB_ = 2.00;
%     J_HH.AX = 20;                                 J_HH.BB_ = 2.00;
     J_HH.AX = 10;                                 J_HH.BB_ = 2.00;
                            J_HH.PX = 1.00;         J_HH.XX_ = 2.00;
    J_HH.BC = 9.00;                                             
    J_HH.BD = 1.50;
    J_HH.BX = 7.50;
        
    % 19F-19F
    J_FF.AB = 8.00;         % General JAB (used in most cases)
    J_FF.AB_large = 15.00;  % JAB used in pople = 'AB_large', 'ABX' and 'ABX3'
     
    J_FF.AC = 3.00;         J_FF.CD = 10.00;        J_FF.AA_ = 10.00;              
    J_FF.AD = 7.00;                                 J_FF.AB_ = 10.00;
    J_FF.AM = 7.00;         J_FF.MP = 9.00;         J_FF.AM_ = 10.00;
    J_FF.AP = 3.00;         J_FF.MX = 0.80;         J_FF.AX_ = 10.00;
    J_FF.AX = 8.00;                                 J_FF.BB_ = 10.00;
                            J_FF.PX = 1.00;         J_FF.XX_ = 10.00;
    J_FF.BC = 10.00;                                            
    J_FF.BD = 10.00;
    J_FF.BX = 10.00;

    
    % 1H-19F
    J_HF.AX = 30.00;
    J_HF.AX_ = 1.00;

    % 13C-1H and 13C-19F
    JC = [150.0 150.0 140.0 200.0];


% T1 and T2 time constants (s)

    % 1H
    t1_1H.A = 10;     t1_1H.B = 1.0;     t2_1H.A = 5;     t2_1H.B = 0.4;
    t1_1H.X = 10;     t1_1H.C = 1.0;     t2_1H.X = 5;     t2_1H.C = 0.4;
    t1_1H.M = 10;     t1_1H.D = 1.0;     t2_1H.M = 5;     t2_1H.D = 0.4;
    t1_1H.P = 1.0;     t1_1H.Y = 1.0;     t2_1H.P = 0.4;     t2_1H.Y = 0.4;
    
    % 19F
    t1_19F.A = 1.0;     t1_19F.B = 1.0;     t2_19F.A = 0.4;     t2_19F.B = 0.4;
    t1_19F.X = 1.0;     t1_19F.C = 1.0;     t2_19F.X = 0.4;     t2_19F.C = 0.4;
    t1_19F.M = 1.0;     t1_19F.D = 1.0;     t2_19F.M = 0.4;     t2_19F.D = 0.4;
    t1_19F.P = 1.0;     t1_19F.Y = 1.0;     t2_19F.P = 0.4;     t2_19F.Y = 0.4;
    
    % 13C
    t1_13C = [100.0 100.0 1.0 1.0];
    t2_13C = [0.5 0.5 0.5 0.5];


%% SET SIMULATION VALUES ----------------------------------------------

% Set the chemical shifts, coupling constants and T1 and T2 time constants
% to be used depending on the values of parameters.isotopes

% 1H first spin system
if strcmp(parameters.isotopes{1}, '1H')
    S = shifts_1H;
    t1_S = t1_1H;
    t2_S = t2_1H;            
    
    % 1H spin system (also optional 13C)
    if length(parameters.isotopes) == 1 || ...
        (length(parameters.isotopes) == 2 && strcmp(parameters.isotopes{2}, '13C'))
        J = J_HH;
        
    % 1H (A spin) and 19F (X spin) heteronuclear spin system (also optional 13C)
    elseif strcmp(parameters.isotopes{2}, '19F')
        V = shifts_19F;
        J_SS = J_HH;
        J_VV = J_FF;
        J_SV = J_HF;
        t1_V = t1_19F;
        t2_V = t2_19F;
        isotope_V = {'19F'};
        
    else % Parameters undefined for that isotope
        error('Spin parameters not defined for that isotope in the pople file.')        
    end

% 19F first spin system    
elseif strcmp(parameters.isotopes{1}, '19F')
    S = shifts_19F;
    t1_S = t1_19F;
    t2_S = t2_19F;
    
    % 19F spin system
    if length(parameters.isotopes) == 1 || ...
        (length(parameters.isotopes) == 2 && strcmp(parameters.isotopes{2}, '13C'))
        J = J_FF;
        
    % 19F (A spin) and 1H (X spin) heteronuclear spin system
    elseif strcmp(parameters.isotopes{2}, '1H')
        V = shifts_1H;
        J_SS = J_FF;
        J_VV = J_HH;
        J_SV = J_HF;
        t1_V = t1_1H;
        t2_V = t2_1H;    
        isotope_V = {'1H'};
        
    else % Parameters undefined for that isotope
        error('Spin parameters not defined for that isotope in the pople file.')        
    end            
    
else
    error("Error - the first element of parameters.isotopes must be '1H' or '19F'.")
end


%% GENERATE SPIN SYSTEM --------------------------------------------------

% Determine if heteronuclear system (not counting 13C)
if (length(unique(parameters.isotopes)) == 1) || ...
    (length(unique(parameters.isotopes)) == 2 && any(strcmp(parameters.isotopes, '13C')))
      het = 'n';
else, het = 'y';
end

% Parse Pople >>

% >> Remove underscore to end
if contains(pople,'_'), temp_pople = pople(1:(regexp(pople,'_'))-1);
else, temp_pople = pople;
end

% >> Generate spins cell array using Pople value
counter = 1;
for k = 1:length(temp_pople)
    x = str2num(temp_pople(k)); % Check if the char is can be converted to num
    if isempty(x)
        spins{counter} = temp_pople(k);
        counter = counter + 1;
    else
        for j = 1:x-1 % if char converts to number then generate x-1 additional spins
            spins{counter} = temp_pople(k-1); % use spin letter that preceeded the number
            counter = counter + 1;
        end
    end
end

% Initialise
num_S = 0; num_V = 0;
    
% Generate inter values by looping through spins array
for i = 1:length(spins)
    if strcmp(spins{i}, 'A') || strcmp(het,'n')    
        inter.zeeman.scalar{i} = S.(char(spins{i}));
        t1(i) = t1_S.(char(spins{i}));
        t2(i) = t2_S.(char(spins{i}));
        num_S = num_S + 1;
    else
        inter.zeeman.scalar{i} = V.(char(spins{i}));
        t1(i) = t1_V.(char(spins{i}));
        t2(i) = t2_V.(char(spins{i}));
        num_V = num_V + 1;
    end        
end

% Pople switch to add coupling
switch pople
    
    case 'A'     
        C13_coupling = [1];
        
    case 'A2'
        C13_coupling = [1 1];
        
    case 'A3'
        C13_coupling = [1 1 1];
        
    case 'AX'
        inter.coupling.scalar{1,2} = J.AX;
        C13_coupling = [1 2];        
    
    case 'AB'
        inter.coupling.scalar{1,2} = J.AB;
        C13_coupling = [1 2];

    case 'AB_large'
        inter.coupling.scalar{1,2} = J.AB_large;
        C13_coupling = [1 2];
        
    case 'AMX'
        inter.coupling.scalar{1,2} = J.AM;
        inter.coupling.scalar{1,3} = J.AX;
        inter.coupling.scalar{2,3} = J.MX;
        C13_coupling = [1 2 3];        
        
    case 'ABX'
        inter.coupling.scalar{1,2} = J.AB_large; % NOTE: Use of large JAB value
        inter.coupling.scalar{1,3} = J.AX;
        inter.coupling.scalar{2,3} = J.BX;
        C13_coupling = [1 1 2];
        
    case 'ABC'
        inter.coupling.scalar{1,2} = J.AB;
        inter.coupling.scalar{1,3} = J.AC;
        inter.coupling.scalar{2,3} = J.BC;
        C13_coupling = [1 2 3];
        
    case 'AX2'
        inter.coupling.scalar{1,2} = J.AX;
        inter.coupling.scalar{1,3} = J.AX;
        C13_coupling = [1 2 2];
        
    case 'AB2'
        inter.coupling.scalar{1,2} = J.AB;
        inter.coupling.scalar{1,3} = J.AB;
        C13_coupling = [1 2 2];
        
    case 'AMPX'
        inter.coupling.scalar{1,2} = J.AM;
        inter.coupling.scalar{1,3} = J.AP;
        inter.coupling.scalar{1,4} = J.AX;       
        inter.coupling.scalar{2,3} = J.MP;  
        inter.coupling.scalar{2,4} = J.MX;
        inter.coupling.scalar{3,4} = J.PX;
        C13_coupling = [1 2 3 4];
        
    case 'ABCD'
        inter.coupling.scalar{1,2} = J.AB;
        inter.coupling.scalar{1,3} = J.AC;
        inter.coupling.scalar{1,4} = J.AD;       
        inter.coupling.scalar{2,3} = J.BC;  
        inter.coupling.scalar{2,4} = J.BD;
        inter.coupling.scalar{3,4} = J.CD;
        C13_coupling = [1 2 3 4];
        
    case 'AX3'
        inter.coupling.scalar{1,2} = J.AX;
        inter.coupling.scalar{1,3} = J.AX;     
        inter.coupling.scalar{1,4} = J.AX;
        C13_coupling = [1 2 2 2];
        
    case 'AB3'
        inter.coupling.scalar{1,2} = J.AB;
        inter.coupling.scalar{1,3} = J.AB;     
        inter.coupling.scalar{1,4} = J.AB;        
        C13_coupling = [1 2 2 2];
        

    case 'A2X2'           
        inter.coupling.scalar{1,3} = J.AX;     
        inter.coupling.scalar{1,4} = J.AX;
        inter.coupling.scalar{2,3} = J.AX;
        inter.coupling.scalar{2,4} = J.AX;       
        C13_coupling = [1 1 2 2];                            

    case 'A2B2'            
        inter.coupling.scalar{1,3} = J.AB;     
        inter.coupling.scalar{1,4} = J.AB;
        inter.coupling.scalar{2,3} = J.AB;
        inter.coupling.scalar{2,4} = J.AB;
        C13_coupling = [1 1 2 2];                     

    case 'AAXX'         
        inter.coupling.scalar{1,2} = J.AA_;
        inter.coupling.scalar{1,3} = J.AX;     
        inter.coupling.scalar{1,4} = J.AX_;
        inter.coupling.scalar{2,3} = J.AX_;
        inter.coupling.scalar{2,4} = J.AX;
        inter.coupling.scalar{3,4} = J.XX_;
        C13_coupling = [1 1 2 2];        
        

    case 'AABB'           
        inter.coupling.scalar{1,2} = J.AA_;
        inter.coupling.scalar{1,3} = J.AB;     
        inter.coupling.scalar{1,4} = J.AB_;
        inter.coupling.scalar{2,3} = J.AB_;
        inter.coupling.scalar{2,4} = J.AB;
        inter.coupling.scalar{3,4} = J.BB_;        
        C13_coupling = [1 1 2 2];                                 

    case 'A2X3'       
        inter.coupling.scalar{1,3} = J.AX;     
        inter.coupling.scalar{1,4} = J.AX;
        inter.coupling.scalar{1,5} = J.AX;
        inter.coupling.scalar{2,3} = J.AX;
        inter.coupling.scalar{2,4} = J.AX;
        inter.coupling.scalar{2,5} = J.AX;       
        C13_coupling = [1 1 2 2 2];                         

    case 'A2B3'         
        inter.coupling.scalar{1,3} = J.AB;     
        inter.coupling.scalar{1,4} = J.AB;
        inter.coupling.scalar{1,5} = J.AB;
        inter.coupling.scalar{2,3} = J.AB;
        inter.coupling.scalar{2,4} = J.AB;
        inter.coupling.scalar{2,5} = J.AB;      
        C13_coupling = [1 1 2 2 2];   

    case 'ABX3'       
        inter.zeeman.scalar = {S.A S.B S.X S.X S.X};
        num_S = length(inter.zeeman.scalar);            
        inter.coupling.scalar{1,2} = J.AB_large; % NOTE: Use of large JAB value           
        inter.coupling.scalar{1,3} = J.AX;     
        inter.coupling.scalar{1,4} = J.AX;
        inter.coupling.scalar{1,5} = J.AX;
        inter.coupling.scalar{2,3} = J.BX;
        inter.coupling.scalar{2,4} = J.BX;
        inter.coupling.scalar{2,5} = J.BX;
        C13_coupling = [1 1 2 2 2];               

    case 'AAMMX'
        % assumed that JAX = JA'X and JMX = JM'X          
        inter.coupling.scalar{1,2} = J.AA_;
        inter.coupling.scalar{1,3} = J.AM;     
        inter.coupling.scalar{1,4} = J.AM_;
        inter.coupling.scalar{1,5} = J.AX; 
        inter.coupling.scalar{2,3} = J.AM_;
        inter.coupling.scalar{2,4} = J.AM;
        inter.coupling.scalar{2,5} = J.AX;
        inter.coupling.scalar{3,4} = J.MM_;
        inter.coupling.scalar{3,5} = J.MX;
        inter.coupling.scalar{4,5} = J.MX;
        C13_coupling = [1 1 2 2 3];        

    case 'AABBC'
        % assumed that JAC = JA'C and JBC = JB'C        
        inter.coupling.scalar{1,2} = J.AA_;
        inter.coupling.scalar{1,3} = J.AB;     
        inter.coupling.scalar{1,4} = J.AB_;
        inter.coupling.scalar{1,5} = J.AC; 
        inter.coupling.scalar{2,3} = J.AB_;
        inter.coupling.scalar{2,4} = J.AB;
        inter.coupling.scalar{2,5} = J.AC;
        inter.coupling.scalar{3,4} = J.BB_;
        inter.coupling.scalar{3,5} = J.BC;
        inter.coupling.scalar{4,5} = J.BC;
        C13_coupling = [1 1 2 2 3];             

    case 'AX_het'
        inter.coupling.scalar{1,2} = J_SV.AX;     
        C13_coupling = [1 2]; 

    case 'AX2_het'
        inter.coupling.scalar{1,2} = J_SV.AX;
        inter.coupling.scalar{1,3} = J_SV.AX;
        C13_coupling = [1 2 2];

    case 'AX3_het'     
        inter.coupling.scalar{1,2} = J_SV.AX;
        inter.coupling.scalar{1,3} = J_SV.AX;
        inter.coupling.scalar{1,4} = J_SV.AX;       
        C13_coupling = [1 2 2 2]; 

    case 'A2X2_het'
        inter.coupling.scalar{1,3} = J_SV.AX;     
        inter.coupling.scalar{1,4} = J_SV.AX;
        inter.coupling.scalar{2,3} = J_SV.AX;
        inter.coupling.scalar{2,4} = J_SV.AX;
        C13_coupling = [1 1 2 2];          

    case 'AAXX_het'
        inter.coupling.scalar{1,2} = J_SS.AA_;
        inter.coupling.scalar{1,3} = J_SV.AX;     
        inter.coupling.scalar{1,4} = J_SV.AX_;
        inter.coupling.scalar{2,3} = J_SV.AX_;
        inter.coupling.scalar{2,4} = J_SV.AX;
        inter.coupling.scalar{3,4} = J_VV.XX_;        
        C13_coupling = [1 1 2 2]; 

    case 'A2X3_het'
        inter.coupling.scalar{1,3} = J_SV.AX;     
        inter.coupling.scalar{1,4} = J_SV.AX;
        inter.coupling.scalar{1,5} = J_SV.AX;
        inter.coupling.scalar{2,3} = J_SV.AX;
        inter.coupling.scalar{2,4} = J_SV.AX;
        inter.coupling.scalar{2,5} = J_SV.AX;
        C13_coupling = [1 1 2 2 2];         

end

% Add 13C
if any(strcmp(parameters.isotopes, '13C'))
    
    % Add 13C chemical shifts, and T1 and T2 time constants    
    num_13C = max(C13_coupling);    
    inter.zeeman.scalar = [inter.zeeman.scalar, shifts_13C{1:num_13C}];        
    t1 = [t1, t1_13C(1:num_13C)];
    t2 = [t2, t2_13C(1:num_13C)];
    
    % Add 13C coupling    
    for i = 1:length(spins)
        inter.coupling.scalar{i,C13_coupling(i)+num_S+num_V} = JC(C13_coupling(i));
    end     
end

% Create sys.isotopes
sys.isotopes = {};
sys.isotopes = [sys.isotopes, repmat({parameters.isotopes{1}}, 1, num_S)];
if exist('isotope_V', 'var')
    sys.isotopes = [sys.isotopes, repmat(isotope_V, 1, num_V)];
end
if any(strcmp(parameters.isotopes, '13C'))
sys.isotopes = [sys.isotopes, repmat({'13C'}, 1, num_13C)];
end

% Set value for last inter.coupling.scalar matrix element
inter.coupling.scalar{length(sys.isotopes),length(sys.isotopes)} = 0;


%% RELAXATION MODEL ------------------------------------------------------

% Default to 't1_t2' model if relaxation model is undefined in params file
if ~isfield(inter, 'relaxation'), inter.relaxation = {'t1_t2'}; end

% Default to 298 K if temperature undefined
if ~isfield(inter, 'temperature'), inter.temperature = 298; end

% t1_t2 parameters
if any(strcmp(inter.relaxation, 't1_t2'))
    if ~isfield(inter, 'equilibrium'), inter.equilibrium = 'zero'; end
    if ~isfield(inter, 'rlx_keep'),    inter.rlx_keep = 'secular'; end
    inter.r1_rates = 1./t1;
    inter.r2_rates = 1./t2;
end

% Redfield parameters
if any(strcmp(inter.relaxation, 'redfield'))
%     error('Error - cannot use as nuclear coordinates not defined for Pople samples')
    if ~isfield(inter, 'equilibrium'), inter.equilibrium = 'dibari'; end
    if ~isfield(inter, 'rlx_keep'),    inter.rlx_keep = 'secular';   end
    if ~isfield(inter, 'tau_c'),       inter.tau_c = {200e-12};      end
end


%% BASIS AND TOLERANCES --------------------------------------------------
   
% Tolerances
sys.tols.prox_cutoff = 5.0;

% Basis set specification
if ~isfield(bas, 'formalism'), bas.formalism = 'sphten-liouv'; end
if ~isfield(bas, 'approximation'), bas.approximation = 'IK-2'; end
if ~isfield(bas, 'connectivity'), bas.connectivity = 'scalar_couplings'; end
if ~isfield(bas, 'space_level')     
    if length(sys.isotopes) < 3, bas.space_level = length(sys.isotopes);
    else, bas.space_level = 3;
    end
end


end
% Simulation ID: 221208-192828
